predict can be applied with a higrad object to obtain predictions and confidence intervals.
# S3 method for higrad
predict(object, newx, alpha = 0.05, type = "link",
prediction.interval = FALSE, ...)a fitted object of class higrad.
matrix of new values for x at which predictions are to be made.
significance level. The confidence level of the interval is thus 1 - alpha.
type of prediction required. Type "link" gives the linear predictors for "logistic"; for "lm" models it gives the fitted values. Type "response" gives the fitted probabilities for "logistic"; for "lm" type "response" is equivalent to type "link".
logical; indicator of whether prediction intervals should be returned instead of confidence intervals.
other prediction options.
A list with components
predicted values.
upper limit of the confidence/prediction intervals.
lower limit of the confidence/prediction intervals.